@@ -4,7 +4,6 @@
 # This module is part of python-pptx and is released under
 # the MIT License: http://www.opensource.org/licenses/mit-license.php
 
-import inspect
 import sys
 
 import pptx.exc as exceptions
@@ -12,9 +11,6 @@ sys.modules['pptx.exceptions'] = exceptions
 
 from pptx.api import(Presentation)
 
-# __all__ = sorted(name for name, obj in locals().items() if not (name.startswith('_') or inspect.ismodule(obj)))
-
-__version__ = '0.2.2'
-
-del inspect, sys
+__version__ = '0.2.3'
 
+del sys
